@@ -1,17 +1,17 @@
-if pidof compiz.real | grep [0-9] > /dev/null
+if pidof compiz | grep [0-9] > /dev/null
 then
 killall compiz.real
 killall compiz
 killall emerald
-xfwm4 &
+xfwm4 --replace &
 gconftool-2 --type bool --set /apps/mintdesktop-xfce/compiz_fusion false
 else
 killall xfwm4
-/usr/lib/linuxmint/xfcemintDesktop/desktopeffects/compiz --sm-disable &
+compiz --replace &
 gconftool-2 --type bool --set /apps/mintdesktop-xfce/compiz_fusion true
 fi 
 sleep 2
-if pidof compiz.real | grep [0-9] > /dev/null
+if pidof compiz | grep [0-9] > /dev/null
 then
 gconftool-2 --type bool --set /apps/mintdesktop-xfce/compiz_fusion true
 else
